@@ -225,7 +225,9 @@ namespace mamba
 
         static ConsoleStream stream();
         static void print(const std::string_view& str, bool force_print = false);
-        static bool prompt(const std::string_view& message, char fallback = '_');
+        static bool prompt(const std::string_view& message,
+                           char fallback = '_',
+                           std::istream& input_stream = std::cin);
 
         ProgressProxy add_progress_bar(const std::string& name, size_t expected_total = 0);
         void init_multi_progress(ProgressBarMode mode = ProgressBarMode::multi);
@@ -250,6 +252,7 @@ namespace mamba
         Console::instance().print_progress(m_idx);
     }
 
+#undef TRACE
 #undef DEBUG
 #undef INFO
 #undef WARNING
@@ -258,6 +261,7 @@ namespace mamba
 
     enum class LogSeverity
     {
+        kTrace,
         kDebug,
         kInfo,
         kWarning,
@@ -314,6 +318,7 @@ namespace mamba
 #undef FATAL
 
 #define LOG(severity) mamba::MessageLogger(__FILE__, __LINE__, severity).stream()
+#define LOG_TRACE LOG(mamba::LogSeverity::kTrace)
 #define LOG_DEBUG LOG(mamba::LogSeverity::kDebug)
 #define LOG_INFO LOG(mamba::LogSeverity::kInfo)
 #define LOG_WARNING LOG(mamba::LogSeverity::kWarning)
